[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# FactSet Concordance client library for Python

[![API Version](https://img.shields.io/badge/api-v2.10.0-blue)]()
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.FactSetConcordance/2.0.0)](https://pypi.org/project/fds.sdk.FactSetConcordance/v/2.0.0)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)



The FactSet Concordance API enables Application Developers and Data Scientists to programmatically discover the FactSet Identifier for a specific Entity or Person based on attributes, such as name, URL, and location.FactSet Identifiers are mapped to industry-standard identifiers, as well as to a comprehensive set of reference data and unique content, to enhance the ability to quickly connect content sets.<p>  

 Using the submitted attributes, the FactSet Concordance API leverages FactSet’s extensive Entity Master, People, and Symbology databases to return potential candidate matches and a proposed match. The result is a concorded FactSet Identifier that can then be used as input throughout FactSet's expanding catalog of Content using our Content APIs or Standard DataFeeds.</p>
 
 <b>There are two types of workflows supported in the API:</b>
 
 <b>Entity & People Match:</b> The first workflow follows traditional API conventions in that a request is accepted and a response is returned synchronously enabling the concordance of up to 25 names in a single request. The response returns a list of 20 candidates as well as a proposed match.
 
 <b>Entity & People Match - Bulk:</b> The second workflow allows you to input a large list of names within a .CSV file in a single request. With this workflow, a task is created for uploading a set of queries. Once the task has completed, the client retrieves the concordance results through the /entity-decisions or /people-decisions endpoint. Note that in the Bulk workflow, only the matches for the records are returned. Candidates are not included.
 
 Once the service has provided a list of concorded FactSet Identifiers, you can then use our Entity Mappings and People Mappings endpoints to further review the universe of mapped identifiers or modify existing records. </p><p><b>Rate limit is set to 10 requests per second</b>.</p>
 
 Methodology Guide link: 
 [https://open.factset.com/api/public/media/download/products/documents/8ca33e81-a7da-4d77-a8cf-2b3a2e868b3d](https://open.factset.com/api/public/media/download/products/documents/8ca33e81-a7da-4d77-a8cf-2b3a2e868b3d)

 


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.10.0
- SDK version: 2.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.FactSetConcordance==2.0.0
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.FactSetConcordance==2.0.0
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.FactSetConcordance
from fds.sdk.FactSetConcordance.api import entity_match_api
from fds.sdk.FactSetConcordance.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.FactSetConcordance.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.FactSetConcordance.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.FactSetConcordance.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = entity_match_api.EntityMatchApi(api_client)
    name = "Tesla" # str | Name of Entity to match.
    country = "US" # str | ISO2 country code corresponding to the entity name that is used when evaluating candidates for a match. For a list of ISO2 Country codes, visit [OA 8754](https://my.apps.factset.com/oa/pages/8754#country). (optional)
    state = "TX" # str | Two-character state code corresponding to the entity name that is used when evaluating candidates for a match. Currently, only US state codes are supported. (optional)
    url = "www.tesla.com" # str | URL corresponding to the entity name that is used when evaluating candidates for a match. (optional)
    include_entity_type = [
        "PUB",
    ] # [str] | Three-character FactSet entity type code used to filter candidates in order to determine the final match result. Only candidates with an entity type specified will be considered for the final match result. Multiple types can be entered separated by commas.   |Entity Type Code|Entity Type Description|Entity Type Code|Entity Type Description|   |---|---|---|---|   |ABS|Asset-Backed|MED|Broadcast Call Sign|   |BAS|Business Association (JP)|MUC|Mutual Fd-Closed End|   |CAC|Consolidated Accounting|MUE|Mutual Fd-ETF|   |CMD|Commodity|MUT|Mutual Fd-Open End|   |COL|College/University|NPO|Non-Profit Organization|   |CUR|Currency|OPD|Operating Division|   |ESP|Emp Stk Ownership Plan|OTH|Other|   |EXT|Extinct|PEF|Pension Fund|   |FAF|Family of Fds (VC/Pvt EQ)|PRO|Real Property|   |FND|Foundation/Endowment|PUB|Public Company|   |FNS|Financing Subsidiary/SPE|PVF|Private Eq Fd/Alt Invt|   |FRX|ForEx|PVT|Private Company|   |GOV|Government|SOV|Sovereign Wealth Fund|   |HED|Hedge Fund|SUB|Subsidiary|   |HOL|Holding Company|TRU|Trust/Trustee|   |IDX|Index|UMB|Umbrella Fund|   |VEN|Venture Capital Fund|JVT|Joint Venture|  (optional)
    exclude_entity_type = [
        "EXT",
    ] # [str] | Three-character FactSet entity type code used to filter candidates in order to determine the final match result. Candidates with an entity type specified will *not* be considered for the final match result. Multiple types can be entered separated by commas.   |Entity Type Code|Entity Type Description|Entity Type Code|Entity Type Description|   |---|---|---|---| |ABS|Asset-Backed|MED|Broadcast Call Sign| |BAS|Business Association (JP)|MUC|Mutual Fd-Closed End| |CAC|Consolidated Accounting|MUE|Mutual Fd-ETF| |CMD|Commodity|MUT|Mutual Fd-Open End| |COL|College/University|NPO|Non-Profit Organization| |CUR|Currency|OPD|Operating Division| |ESP|Emp Stk Ownership Plan|OTH|Other| |EXT|Extinct|PEF|Pension Fund| |FAF|Family of Fds (VC/Pvt EQ)|PRO|Real Property| |FND|Foundation/Endowment|PUB|Public Company| |FNS|Financing Subsidiary/SPE|PVF|Private Eq Fd/Alt Invt| |FRX|ForEx|PVT|Private Company| |GOV|Government|SOV|Sovereign Wealth Fund| |HED|Hedge Fund|SUB|Subsidiary| |HOL|Holding Company|TRU|Trust/Trustee| |IDX|Index|UMB|Umbrella Fund| |VEN|Venture Capital Fund|JVT|Joint Venture|  (optional)
    include_entity_sub_type = [
        "PR",
    ] # [str] | Two-character FactSet entity subtype code used to filter candidates in order to determine the final match result. Only candidates with an entity subtype specified will be considered for the final match result. Multiple types can be entered separated by commas.   |Entity Subtype Code|Entity Subtype Description|Entity Subtype Code|Entity Subtype Description|   |---|---|---|---|   |AR|Arbitrage|IC|Investment Company|   |BM|Bank Investment Division|IN|Insurance Company|   |BR|Broker|MF|Mutual Fund Manager|   |CP|Corporate|ML|Master Ltd Part|   |CU|Custodial|MM|Market Maker|   |FF|Fund of Funds Manager|PB|Private Banking/Wealth Mgmt|   |FH|Fund of Hedge Funds Manager|PF|Pension Fund Manager|   |FO|Foundation/Endowment Manager|PP|Real Estate Manager|   |FS|Fund Distributor|RE|Research Firm|   |FU|Fund|SB|Subsidiary Branch|   |FY|Family Office|ST|Stock Borrowing/Lending|   |GV|Govt (Fed/Local/Agency)|SV|Sovereign Wealth Manager|   |HF|Hedge Fund Manager|VC|Venture Capital/Pvt Equity|   |IA|Investment Adviser|   |IB|Investment Banking|  (optional)
    exclude_entity_sub_type = [
        "HF",
    ] # [str] | Two-character FactSet entity subtype code used to filter candidates in order to determine the final match result. Candidates with an entity subtype specified will not be considered for the final match result. Multiple types can be entered separated by commas. |Entity Subtype Code|Entity Subtype Description|Entity Subtype Code|Entity Subtype Description| |---|---|---|---| |AR|Arbitrage|IC|Investment Company| |BM|Bank Investment Division|IN|Insurance Company| |BR|Broker|MF|Mutual Fund Manager| |CP|Corporate|ML|Master Ltd Part| |CU|Custodial|MM|Market Maker| |FF|Fund of Funds Manager|PB|Private Banking/Wealth Mgmt| |FH|Fund of Hedge Funds Manager|PF|Pension Fund Manager| |FO|Foundation/Endowment Manager|PP|Real Estate Manager| |FS|Fund Distributor|RE|Research Firm| |FU|Fund|SB|Subsidiary Branch| |FY|Family Office|ST|Stock Borrowing/Lending| |GV|Govt (Fed/Local/Agency)|SV|Sovereign Wealth Manager| |HF|Hedge Fund Manager|VC|Venture Capital/Pvt Equity| |IA|Investment Adviser| |IB|Investment Banking|  (optional)
    include_parent = False # bool | Flag to include parent entities in the list of candidates. This parameter does not influence the match result. (optional) if omitted the server will use the default value of False
    bbg_figi = "BBG000N9P426" # str | Input identifiers for the Bloomberg Listing/Regional/Security ID symbol type. (optional)
    bbg_ticker = "TSLA UW" # str | Input identifiers for the Bloomberg Listing and Regional Ticker symbol Type. (optional)
    bic = "TSLAUS66" # str | Input identifiers for the BICCode - Bank Indentification Code symbol Type. (optional)
    cik = "1318605" # str | Input identifiers for the CIK - Edgar Central Index Keys symbol type. (optional)
    crd = "CRD" # str | Input identifiers for the CRD - Central Registration Depository symbol type. (optional)
    cusip = "88160R101" # str | Input identifiers for the CUSIP symbol type. (optional)
    ein = "912197729" # str | Input identifiers for the EIN - Employer Identification Number symbol type. (optional)
    factset_id = "006XY7-E" # str | Input identifiers for the type FactSet Identifier - FactSet -E,-S,-R, -L Permanent Identifier symbol type. (optional)
    fitch = "FitchCreditRating" # str | Input identifiers for the Fitch - Fitch Ratings symbol type. (optional)
    gvkey = "GVKey" # str | Input identifiers for the type GVKEY - Compustat Global Company Key symbol type. (optional)
    gvkey_iid = "GVKeyIssueIdentifier" # str | Input identifiers for the type GVKEY+IID - Compustat Global Company Key and Issue Identifier symbol type. (optional)
    isin = "US88160R1014" # str | Input identifiers for the ISIN - International Securities Identification Number symbol type. (optional)
    jcn = "JCN" # str | Input identifiers for the type JCN - Japanese Corporate Number symbol type. (optional)
    lei = "54930043XZGB27CTOV49" # str | Input identifiers for the LEI - Legal Entity Identifier symbol type (optional)
    lxid = "LXID" # str | Input identifiers for the type LXID - Markit Syndicated Loan Identifier symbol type. (optional)
    md = "823642219" # str | Input identifiers for the Moody's Ratings Identifier type. (optional)
    red_code = "RedCode" # str | Input identifiers for the type Red Code - Markit Reference Entity Identifier symbol type. (optional)
    rssd = "FederalReserveRSSDIdentifier" # str | Input identifiers for the RSSD - Federal Reserve RSSD symbol typ. (optional)
    sedol = "B616C79" # str | Input identifiers for the SEDOL symbol type. (optional)
    spr = "562703" # str | Input identifiers for the Price Ticker symbol type. (optional)
    ticker = "PriceTicker" # str | Input identifiers for the Price Ticker symbol type. (optional)
    ticker_exchange = "TSLA-NAS" # str | Input identifiers for the TickerExchange. (optional)
    ticker_region = "TSLA-US" # str | Input identifiers for the TickerRegion. (optional)
    ukch = "UKCompanyHouse" # str | Input identifiers for the UKCH - UK Company House symbol type. (optional)
    valoren = "VALOR" # str | Input identifiers for the Valoren (\"Valor\") symbol type. (optional)
    wkn = "A1CX3T" # str | Input identifiers for the WKN - German Securities symbol type. (optional)
    candidates_count = 40 # int | Maximum number of candidates to be returned. Parent entities, when includeParent is true, are not included in this count. <p>*minimum - 20*</p> <p>*maximum - 100*</p> (optional)

    try:
        # Get Entity Candidates and Matches for a single name and attributes.
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_entity_match(name, country=country, state=state, url=url, include_entity_type=include_entity_type, exclude_entity_type=exclude_entity_type, include_entity_sub_type=include_entity_sub_type, exclude_entity_sub_type=exclude_entity_sub_type, include_parent=include_parent, bbg_figi=bbg_figi, bbg_ticker=bbg_ticker, bic=bic, cik=cik, crd=crd, cusip=cusip, ein=ein, factset_id=factset_id, fitch=fitch, gvkey=gvkey, gvkey_iid=gvkey_iid, isin=isin, jcn=jcn, lei=lei, lxid=lxid, md=md, red_code=red_code, rssd=rssd, sedol=sedol, spr=spr, ticker=ticker, ticker_exchange=ticker_exchange, ticker_region=ticker_region, ukch=ukch, valoren=valoren, wkn=wkn, candidates_count=candidates_count)

        pprint(api_response)
    except fds.sdk.FactSetConcordance.ApiException as e:
        print("Exception when calling EntityMatchApi->get_entity_match: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Get Entity Candidates and Matches for a single name and attributes.
    #     api_response, http_status_code, response_headers = api_instance.get_entity_match_with_http_info(name, country=country, state=state, url=url, include_entity_type=include_entity_type, exclude_entity_type=exclude_entity_type, include_entity_sub_type=include_entity_sub_type, exclude_entity_sub_type=exclude_entity_sub_type, include_parent=include_parent, bbg_figi=bbg_figi, bbg_ticker=bbg_ticker, bic=bic, cik=cik, crd=crd, cusip=cusip, ein=ein, factset_id=factset_id, fitch=fitch, gvkey=gvkey, gvkey_iid=gvkey_iid, isin=isin, jcn=jcn, lei=lei, lxid=lxid, md=md, red_code=red_code, rssd=rssd, sedol=sedol, spr=spr, ticker=ticker, ticker_exchange=ticker_exchange, ticker_region=ticker_region, ukch=ukch, valoren=valoren, wkn=wkn, candidates_count=candidates_count)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetConcordance.ApiException as e:
    #     print("Exception when calling EntityMatchApi->get_entity_match: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Get Entity Candidates and Matches for a single name and attributes.
    #     async_result = api_instance.get_entity_match_async(name, country=country, state=state, url=url, include_entity_type=include_entity_type, exclude_entity_type=exclude_entity_type, include_entity_sub_type=include_entity_sub_type, exclude_entity_sub_type=exclude_entity_sub_type, include_parent=include_parent, bbg_figi=bbg_figi, bbg_ticker=bbg_ticker, bic=bic, cik=cik, crd=crd, cusip=cusip, ein=ein, factset_id=factset_id, fitch=fitch, gvkey=gvkey, gvkey_iid=gvkey_iid, isin=isin, jcn=jcn, lei=lei, lxid=lxid, md=md, red_code=red_code, rssd=rssd, sedol=sedol, spr=spr, ticker=ticker, ticker_exchange=ticker_exchange, ticker_region=ticker_region, ukch=ukch, valoren=valoren, wkn=wkn, candidates_count=candidates_count)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.FactSetConcordance.ApiException as e:
    #     print("Exception when calling EntityMatchApi->get_entity_match: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Get Entity Candidates and Matches for a single name and attributes.
    #     async_result = api_instance.get_entity_match_with_http_info_async(name, country=country, state=state, url=url, include_entity_type=include_entity_type, exclude_entity_type=exclude_entity_type, include_entity_sub_type=include_entity_sub_type, exclude_entity_sub_type=exclude_entity_sub_type, include_parent=include_parent, bbg_figi=bbg_figi, bbg_ticker=bbg_ticker, bic=bic, cik=cik, crd=crd, cusip=cusip, ein=ein, factset_id=factset_id, fitch=fitch, gvkey=gvkey, gvkey_iid=gvkey_iid, isin=isin, jcn=jcn, lei=lei, lxid=lxid, md=md, red_code=red_code, rssd=rssd, sedol=sedol, spr=spr, ticker=ticker, ticker_exchange=ticker_exchange, ticker_region=ticker_region, ukch=ukch, valoren=valoren, wkn=wkn, candidates_count=candidates_count)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetConcordance.ApiException as e:
    #     print("Exception when calling EntityMatchApi->get_entity_match: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.FactSetConcordance

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.FactSetConcordance.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.FactSetConcordance

configuration = fds.sdk.FactSetConcordance.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.FactSetConcordance

configuration = fds.sdk.FactSetConcordance.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.FactSetConcordance

configuration = fds.sdk.FactSetConcordance.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/content*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*EntityMatchApi* | [**get_entity_match**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMatchApi.md#get_entity_match) | **GET** /factset-concordance/v2/entity-match | Get Entity Candidates and Matches for a single name and attributes.
*EntityMatchApi* | [**get_entity_match_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMatchApi.md#get_entity_match_for_list) | **POST** /factset-concordance/v2/entity-match | Get a list of Entity Candidates and Matches for a requested list of up to 25 names and attributes.
*EntityMatchBulkApi* | [**get_entity_decisions**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMatchBulkApi.md#get_entity_decisions) | **GET** /factset-concordance/v2/entity-decisions | Get the decisions of matches for the requested taskId.
*EntityMatchBulkApi* | [**get_entity_task_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMatchBulkApi.md#get_entity_task_for_list) | **POST** /factset-concordance/v2/entity-task | Input a file with names and attributes, creating a taskId.
*EntityMatchBulkApi* | [**get_entity_task_status**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMatchBulkApi.md#get_entity_task_status) | **GET** /factset-concordance/v2/entity-task-status | Gets the status of the requested taskId or all tasks for a User
*MappingsApi* | [**get_entity_mapping_delete_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/MappingsApi.md#get_entity_mapping_delete_for_list) | **POST** /factset-concordance/v2/entity-mapping-delete | Deletes mapping specified by the client.
*MappingsApi* | [**get_entity_mapping_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/MappingsApi.md#get_entity_mapping_for_list) | **POST** /factset-concordance/v2/entity-mapping | Saves a single-mapping specified by the client.
*MappingsApi* | [**get_entity_universe**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/MappingsApi.md#get_entity_universe) | **GET** /factset-concordance/v2/entity-universe | Retrieve all saved mappings within a requested universe
*MappingsApi* | [**get_entity_universe_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/MappingsApi.md#get_entity_universe_for_list) | **POST** /factset-concordance/v2/entity-universe | Retrieve all saved mappings within a requested universe or large list of client ids
*PeopleMappingApi* | [**get_people_mapping_delete_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMappingApi.md#get_people_mapping_delete_for_list) | **POST** /factset-concordance/v2/people-mapping-delete | Deletes mapping specified by the client.
*PeopleMappingApi* | [**get_people_mapping_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMappingApi.md#get_people_mapping_for_list) | **POST** /factset-concordance/v2/people-mapping | Saves a single-mapping specified by the client.
*PeopleMappingApi* | [**get_people_universe**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMappingApi.md#get_people_universe) | **GET** /factset-concordance/v2/people-universe | Retrieve all saved mappings within a requested universe
*PeopleMappingApi* | [**get_people_universe_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMappingApi.md#get_people_universe_for_list) | **POST** /factset-concordance/v2/people-universe | Retrieve all saved mappings within a requested universe or large list of client ids
*PeopleMatchApi* | [**get_people_match**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMatchApi.md#get_people_match) | **GET** /factset-concordance/v2/people-match | Find potential people matches given a person&#39;s name.People matches can be retrieved using person&#39;s name and other attributes like firstname, middlename and lastname.
*PeopleMatchApi* | [**get_people_match_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMatchApi.md#get_people_match_for_list) | **POST** /factset-concordance/v2/people-match | Find potential people matches given a person&#39;s name.
*PeopleMatchBulkApi* | [**get_people_decisions**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMatchBulkApi.md#get_people_decisions) | **GET** /factset-concordance/v2/people-decisions | Get the decisions of matches for the requested taskId.
*PeopleMatchBulkApi* | [**get_people_task_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMatchBulkApi.md#get_people_task_for_list) | **POST** /factset-concordance/v2/people-task | Create a People Concordance Task.
*PeopleMatchBulkApi* | [**get_people_task_status**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMatchBulkApi.md#get_people_task_status) | **GET** /factset-concordance/v2/people-task-status | Get the Status of the People Tasks.
*SnowflakeApi* | [**get_snowflake_entity_match_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/SnowflakeApi.md#get_snowflake_entity_match_for_list) | **POST** /factset-concordance/v2/snowflake-entity-match | Perform an entity search and return a snowflake-friendly response. Up to 25 Names per request.
*SnowflakeApi* | [**snowflake_entity_mapping_post**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/SnowflakeApi.md#snowflake_entity_mapping_post) | **POST** /factset-concordance/v2/snowflake-entity-mapping | Save entity mappings to a universe
*UniversesApi* | [**get_entity_universe_statistics**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UniversesApi.md#get_entity_universe_statistics) | **GET** /factset-concordance/v2/entity-universe-statistics | Get statistics on a given universe
*UniversesApi* | [**get_universe_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UniversesApi.md#get_universe_for_list) | **POST** /factset-concordance/v2/universe | Create a new universe
*UniversesApi* | [**get_universe_statistics**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UniversesApi.md#get_universe_statistics) | **GET** /factset-concordance/v2/universe-statistics | Get statistics on a given universe
*UniversesApi* | [**get_universes**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UniversesApi.md#get_universes) | **GET** /factset-concordance/v2/universes | Fetch metadata for universes
*UniversesApi* | [**get_update_universe_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UniversesApi.md#get_update_universe_for_list) | **POST** /factset-concordance/v2/update-universe | Update metadata for an existing universe


## Documentation For Models

 - [CreateUniverseRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/CreateUniverseRequest.md)
 - [EntityDecisionsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityDecisionsResponse.md)
 - [EntityMapping](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMapping.md)
 - [EntityMappingDeleteRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMappingDeleteRequest.md)
 - [EntityMappingDeleteResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMappingDeleteResponse.md)
 - [EntityMappingRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMappingRequest.md)
 - [EntityMappingResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMappingResponse.md)
 - [EntityMatch](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMatch.md)
 - [EntityMatchRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMatchRequest.md)
 - [EntityMatchRequestInput](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMatchRequestInput.md)
 - [EntityMatchesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityMatchesResponse.md)
 - [EntityResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityResponse.md)
 - [EntityTaskResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityTaskResponse.md)
 - [EntityTaskStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityTaskStatus.md)
 - [EntityTaskStatusResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityTaskStatusResponse.md)
 - [EntityUniverseRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityUniverseRequest.md)
 - [EntityUniverseResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityUniverseResponse.md)
 - [EntityUniverseStatisticsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/EntityUniverseStatisticsResponse.md)
 - [ErrorResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/ErrorResponse.md)
 - [ErrorResponseSubErrors](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/ErrorResponseSubErrors.md)
 - [MapStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/MapStatus.md)
 - [PeopleDecisions](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleDecisions.md)
 - [PeopleDecisionsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleDecisionsResponse.md)
 - [PeopleMapping](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMapping.md)
 - [PeopleMappingDeleteResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMappingDeleteResponse.md)
 - [PeopleMappingRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMappingRequest.md)
 - [PeopleMappingResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMappingResponse.md)
 - [PeopleMatch](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMatch.md)
 - [PeopleMatchRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMatchRequest.md)
 - [PeopleMatchRequestInput](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMatchRequestInput.md)
 - [PeopleMatchesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleMatchesResponse.md)
 - [PeopleTask](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleTask.md)
 - [PeopleTaskResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleTaskResponse.md)
 - [PeopleTaskStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleTaskStatus.md)
 - [PeopleTaskStatusResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleTaskStatusResponse.md)
 - [PeopleUniverseRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleUniverseRequest.md)
 - [PeopleUniverseResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/PeopleUniverseResponse.md)
 - [SnowflakeEntityMappingRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/SnowflakeEntityMappingRequest.md)
 - [SnowflakeEntityMappingResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/SnowflakeEntityMappingResponse.md)
 - [SnowflakeEntityMatchRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/SnowflakeEntityMatchRequest.md)
 - [SnowflakeEntityMatchResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/SnowflakeEntityMatchResponse.md)
 - [Universe](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/Universe.md)
 - [UniverseMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UniverseMeta.md)
 - [UniverseMetaResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UniverseMetaResponse.md)
 - [UniverseStatistics](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UniverseStatistics.md)
 - [UniverseStatisticsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UniverseStatisticsResponse.md)
 - [UniversesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UniversesResponse.md)
 - [UpdateUniverseRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetConcordance/v2/docs/UpdateUniverseRequest.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.FactSetConcordance.apis and fds.sdk.FactSetConcordance.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.FactSetConcordance.api.default_api import DefaultApi`
- `from fds.sdk.FactSetConcordance.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.FactSetConcordance
from fds.sdk.FactSetConcordance.apis import *
from fds.sdk.FactSetConcordance.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

